@@ -4,14 +4,10 @@ import pytest
 def test_defaults_and_stale_choices(api):
     config = api.prefix_config()
     config.f
-    f = {
-        'choice': 'f_a', 'f_a': 'some string'
-    }
+    f = {"choice": "f_a", "f_a": "some string"}
     assert config.f.serialize(config.DICT) == f
 
-    f = {
-        'choice': 'f_b', 'f_b': 4.25
-    }
+    f = {"choice": "f_b", "f_b": 4.25}
     config = api.prefix_config()
     config.f.deserialize(f)
     assert config.f._properties == f
@@ -55,7 +51,7 @@ def test_x_include(api):
     assert "m_param2" in config.e._TYPES
 
 
-@pytest.mark.parametrize('ipv4', ["1.1.1.1", "01.002.003.4", "0.0.0.0"])
+@pytest.mark.parametrize("ipv4", ["1.1.1.1", "01.002.003.4", "0.0.0.0"])
 def test_x_pattern_ipv4_good_value(default_config, ipv4):
     default_config.ipv4_pattern.ipv4.value = ipv4
     try:
@@ -64,7 +60,17 @@ def test_x_pattern_ipv4_good_value(default_config, ipv4):
         pytest.fail("ipv4 pattern failed to serialize")
 
 
-@pytest.mark.parametrize('ipv6', ["::", " :: ", "1::", "::1", "abcd::abcd", "abcd:abcd:abcd:abcd:abcd:abcd:abcd:abcd"])
+@pytest.mark.parametrize(
+    "ipv6",
+    [
+        "::",
+        " :: ",
+        "1::",
+        "::1",
+        "abcd::abcd",
+        "abcd:abcd:abcd:abcd:abcd:abcd:abcd:abcd",
+    ],
+)
 def test_x_pattern_ipv6_good_value(default_config, ipv6):
     default_config.ipv6_pattern.ipv6.value = ipv6
     try:
@@ -73,7 +79,7 @@ def test_x_pattern_ipv6_good_value(default_config, ipv6):
         pytest.fail("ipv6 pattern failed to serialize")
 
 
-@pytest.mark.parametrize('mac', ["ab:ab:ab:ab:ab:ab"])
+@pytest.mark.parametrize("mac", ["ab:ab:ab:ab:ab:ab"])
 def test_x_pattern_mac_good_value(default_config, mac):
     default_config.mac_pattern.mac.value = mac
     try:
@@ -82,7 +88,7 @@ def test_x_pattern_mac_good_value(default_config, mac):
         pytest.fail("mac pattern failed to serialize")
 
 
-@pytest.mark.parametrize('integer', [0, 100, 255])
+@pytest.mark.parametrize("integer", [0, 100, 255])
 def test_x_pattern_integer_good_value(default_config, integer):
     default_config.integer_pattern.integer.value = integer
     try:
@@ -124,7 +130,9 @@ def test_x_pattern_mac_good_and_bad_list(default_config, mac):
             pytest.fail("Invalid mac list is not proper in error message")
 
 
-@pytest.mark.parametrize("integer", [["abcd::abcd::", 10, 3, 255, 256, "ab:ab:ab:ab:ab:ab"]])
+@pytest.mark.parametrize(
+    "integer", [["abcd::abcd::", 10, 3, 255, 256, "ab:ab:ab:ab:ab:ab"]]
+)
 def test_x_pattern_integer_good_and_bad_list(default_config, integer):
     default_config.integer_pattern.integer.values = integer
     try:
@@ -138,29 +146,33 @@ def test_x_pattern_integer_good_and_bad_list(default_config, integer):
 @pytest.mark.parametrize("direction", ["increment", "decrement"])
 @pytest.mark.parametrize("index", list(range(4)))
 def test_x_pattern_good_inc_dec(default_config, index, direction):
-    start = ['1.1.1.1', '2000::1', '00:00:00:00:00:0a', 10]
-    step = ['0.1.1.0', '::1', '00:00:00:00:00:01', 1]
+    start = ["1.1.1.1", "2000::1", "00:00:00:00:00:0a", 10]
+    step = ["0.1.1.0", "::1", "00:00:00:00:00:01", 1]
     count = [100, 100, 100, 100]
-    enum = ['ipv4', 'ipv6', 'mac', 'integer']
-    enum_obj = getattr(getattr(default_config, '%s_pattern' % enum[index]), enum[index])
+    enum = ["ipv4", "ipv6", "mac", "integer"]
+    enum_obj = getattr(
+        getattr(default_config, "%s_pattern" % enum[index]), enum[index]
+    )
     dir_obj = getattr(enum_obj, direction)
     dir_obj.start = start[index]
     dir_obj.step = step[index]
     dir_obj.count = count[index]
     try:
         default_config.serialize(default_config.DICT)
-    except TypeError as e:
+    except TypeError:
         pytest.fail("%s with %s Failed to serialize" % (enum, direction))
 
 
 @pytest.mark.parametrize("direction", ["increment", "decrement"])
 @pytest.mark.parametrize("index", list(range(4)))
 def test_x_pattern_bad_inc_dec(default_config, index, direction):
-    start = ['1.1.1.1', '2000::1', '00:00:00:00:00:00', 10]
-    step = [1, 10, '00:00:00:00:0001', -1]
+    start = ["1.1.1.1", "2000::1", "00:00:00:00:00:00", 10]
+    step = [1, 10, "00:00:00:00:0001", -1]
     count = [100, 100, 100, 100]
-    enum = ['ipv4', 'ipv6', 'mac', 'integer']
-    enum_obj = getattr(getattr(default_config, '%s_pattern' % enum[index]), enum[index])
+    enum = ["ipv4", "ipv6", "mac", "integer"]
+    enum_obj = getattr(
+        getattr(default_config, "%s_pattern" % enum[index]), enum[index]
+    )
     dir_obj = getattr(enum_obj, direction)
     dir_obj.start = start[index]
     dir_obj.step = step[index]
@@ -187,5 +199,6 @@ def test_int_64_format(api, default_config):
     except TypeError as e:
         print(e)
 
+
 if __name__ == "__main__":
     pytest.main(["-v", "-s", __file__])
